/*******************************************************************************
 * Copyright (C) 2002, 2003
 * ingenieurbuero fuer innovative informationstechnik (iiit)
 * Dipl.-Ing. Joerg Beckmann, Dortmund, Germany
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * version $Id: ResolverPluginIf.java,v 1.8 2003/04/13 21:09:56 joerg Exp $
 ******************************************************************************/

package de.iiit.access.server.api;

import de.iiit.access.common.api.*;

import java.util.*;

/** Classes implementing this interfaces can be loaded a resolver plug-in into the
 * AccessServer.
 * @version $Revision: 1.8 $ $Date: 2003/04/13 21:09:56 $
 */
public interface ResolverPluginIf extends ThreadPluginIf
{
    /** Resolves the expression on top of the stack. If the result is also an expression
     * the parser has to be called to evaluate it.
     * @param argStack This stack includes all expressions and subexpressions of the current tree
     * inside the orginal expression.
     * @throws ParserException ParserException if there is something wrong with the expression. The most common cases are syntax
     * errors or circular references within the expression.
     * @return The set of users described by the expression.
     */    
    public Set resolve(ParserStackIf argStack) throws ParserException;
    
    /** The evaluation is optimized in such way that
     * it only retrieves information regarding the given user name.
     * @param argStack This stack includes all expressions and subexpressions of the current tree
     * inside the orginal expression.
     * @param name The name of the user for whom the expression should be resolved.
     * @throws ParserException if there is something wrong with the expression. The most common cases are syntax
     * errors or circular references within the expression.
     * @return An optimized set of users. It is guaranteed that it is correct for the given user
     * but it is not guaranteed that it includes all users described by the expression.
     */    
    public Set resolve(ParserStackIf argStack, String name) throws ParserException;
    
    /** Verifies whether a user exists in the user database.
     * @param uid the user ID.
     * @return true if the user exists or if there is no user database, false if the user
     * doesn't exist.
     */    
    public boolean verifyUser(String uid);
}

/**
 * $Log: ResolverPluginIf.java,v $
 * Revision 1.8  2003/04/13 21:09:56  joerg
 * Package structure modified
 *
 * Revision 1.7  2003/04/13 20:16:41  joerg
 * Package structure modified
 *
 * Revision 1.6  2003/04/07 20:08:49  joerg
 * Improved JavaDoc.
 *
 * Revision 1.5  2003/01/17 19:53:59  joerg
 * Neue Methode verifyUser()
 *
 * Revision 1.4  2003/01/01 21:04:17  joerg
 * Copyright-Statement aktualisiert
 *
 * Revision 1.3  2002/12/23 11:23:00  joerg
 * Da es auch Resolver mit Hintergrund-Prozessen gibt,
 * wird dieses Interface jetzt von ThreadPluginIf abgeleitet.
 *
 * Revision 1.2  2002/12/22 16:57:33  joerg
 * no message
 *
 * Revision 1.1  2002/12/19 15:24:23  joerg
 * Reparatur des CVS-Repositories
 *
 * Revision 1.5  2002/12/09 19:29:17  joerg
 * Versionsdaten in allen JavaDoc-Klassenbeschreibungen ergaenzt
 *
 * Revision 1.4  2002/12/09 16:32:26  joerg
 * JavaDoc Kommentare ergaenzt
 *
 * Revision 1.3  2002/11/27 16:40:57  joerg
 * Parameteruebergabe geaendert, um circulaere Recursion
 * zu erkennen
 *
 * Revision 1.2  2002/11/26 14:45:23  joerg
 * Methode getInstance() entfernt.
 *
 * Revision 1.1  2002/11/26 10:55:08  joerg
 * Package exprparser durch parser erstzt.
 *
 */
